# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Net-DNS-Resolver-Programmable
Version:	0.009
Release:	17.%{__distinit}%{__distvers}
Summary:	Programmable DNS resolver class for offline emulation of DNS
# License contradicts itself, saying "same as perl" (which would be (GPL-1.0-or-later OR Artistic-1.0-Perl))
# but then going on to clarify that as "either the GNU General Public License (version 2 or later) or the Artistic License"
# Clarification requested at https://rt.cpan.org/Ticket/Display.html?id=147412
License:	GPL-2.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Net-DNS-Resolver-Programmable
Source0:	https://cpan.metacpan.org/modules/by-module/Net/Net-DNS-Resolver-Programmable-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(constant)
BuildRequires:	perl(Net::DNS) >= 0.69
BuildRequires:	perl(Net::DNS::Packet)
BuildRequires:	perl(Net::DNS::Resolver)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Test::More)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
Net::DNS::Resolver::Programmable is a Net::DNS::Resolver descendant class
that allows a virtual DNS to be emulated instead of querying the real DNS.
A set of static DNS records may be supplied, or arbitrary code may be
specified as a means for retrieving DNS records, or even generating them
on the fly.

%prep
%setup -q -n Net-DNS-Resolver-Programmable-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc CHANGES README TODO
%{perl_vendorlib}/Net/
%{_mandir}/man3/Net::DNS::Resolver::Programmable.3*

%changelog
* Wed Mar 29 2023 Paul Howarth <paul@city-fan.org> - 0.009-17
- Use SPDX-format license tag
- Drop support for building with rpm < 4.9
- Use %%license unconditionally

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 0.009-6
- Perl 5.30 rebuild

* Tue Jul 25 2017 Paul Howarth <paul@city-fan.org> - 0.009-1
- Update to 0.009
  - Cleaner way to handle both arrays of strings and Net::DNS::Packet objects
    (CPAN RT#122542)
  - Extend tests to cover non-mocked queries too

* Mon Jul 24 2017 Paul Howarth <paul@city-fan.org> - 0.008-1
- Update to 0.008
  - Add Scalar::Util to dependencies

* Thu Jul 20 2017 Paul Howarth <paul@city-fan.org> - 0.007-1
- Update to 0.007
  - Fix handling pre-prepared ::Packet objects passed to send()
  - Additional tests

* Mon Jul 17 2017 Paul Howarth <paul@city-fan.org> - 0.006-1
- Update to 0.006
  - Don't demand 5.10, work on perl ≥ 5.6
  - No taint mode flag in t/01-basic.t
  - Avoid problems with our $VERSION = '...' on one line

* Fri Jul 14 2017 Paul Howarth <paul@city-fan.org> - 0.005-1
- Update to 0.005
  - BIGPRESH taking over maintainership of this seemingly orphaned but very
    useful distribution
  - Avoid deprecated make_query_packet() call (CPAN RT#109266)
  - Remove debian/ subdir (CPAN RT#108522)
  - Regenerate README via pod2readme
  - Fix version number in older changelog entry
  - Remove use of deprecated qv()
  - Import rcode list from Net::DNS (CPAN RT#96390)
- This release by BIGPRESH → update source URL
- Switch to ExtUtils::MakeMaker flow
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Fri Sep  9 2016 Paul Howarth <paul@city-fan.org> - 0.003-24
- Classify buildreqs by usage

* Fri Sep 12 2014 Paul Howarth <paul@city-fan.org> - 0.003-20
- Perl 5.20 rebuild

* Thu Jul 24 2014 Paul Howarth <paul@city-fan.org> - 0.003-19
- Do not use private Net::DNS API removed in Net-DNS-0.75
  (#1099382, CPAN RT#95901)
- Use %%license where possible
- Drop %%defattr, redundant since rpm 4.4

* Wed Jul  4 2012 Paul Howarth <paul@city-fan.org> - 0.003-12
- BR: perl(base) and perl(constant)
- BR: perl(Net::DNS::Packet) and perl(Net::DNS::Resolver) rather than
  perl(Net::DNS)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Don't need to run test suite with LC_ALL=C

* Tue Jul  5 2011 Paul Howarth <paul@city-fan.org> - 0.003-9
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 0.003-8
- Rebuild for perl 5.12.1 in Rawhide

* Thu Jun  3 2010 Paul Howarth <paul@city-fan.org> - 0.003-7
- Fix dist tag for RHEL-6 Beta

* Mon Feb  8 2010 Paul Howarth <paul@city-fan.org> - 0.003-6
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Wed Jun 24 2009 Paul Howarth <paul@city-fan.org> - 0.003-5
- Define RPM macros in global scope

* Thu Oct 16 2008 Paul Howarth <paul@city-fan.org> - 0.003-4
- Import from Fedora
- Add runtime dep for base module perl(Net::DNS::Resolver)

* Wed Mar  5 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.003-3
- Rebuild for new perl

* Wed Jul 11 2007 Steven Pritchard <steve@kspei.com> - 0.003-2
- Rebuild

* Tue Jul 10 2007 Steven Pritchard <steve@kspei.com> - 0.003-1
- Specfile autogenerated by cpanspec 1.72
- Add "v" to files and path names
- Drop explicit redundant dependencies
